==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AQuotedName.h <==
// public final class soot.jimple.parser.node.AQuotedName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 57a68fb97992878e soot_jimple_parser_node_AQuotedName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class a249bf92047679aa soot_jimple_parser_node_PName

// header file dependencies
// @dep_header soot_jimple_parser_node_PName

#include "soot/jimple/parser/node/PName.h"

#ifndef _JC_soot_jimple_parser_node_AQuotedName_H_
#define _JC_soot_jimple_parser_node_AQuotedName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TQuotedName$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AQuotedName$sub_refs	_jc_soot_jimple_parser_node_AQuotedName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs	_jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$refs	_jc_soot_jimple_parser_node_AQuotedName$refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$nonrefs	_jc_soot_jimple_parser_node_AQuotedName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$object	_jc_soot_jimple_parser_node_AQuotedName$object;

typedef const struct _jc_soot_jimple_parser_node_AQuotedName$vmethods	_jc_soot_jimple_parser_node_AQuotedName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AQuotedName$vtable	_jc_soot_jimple_parser_node_AQuotedName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AQuotedName$vtype	_jc_soot_jimple_parser_node_AQuotedName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AQuotedName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *);
extern void _jc_soot_jimple_parser_node_AQuotedName$method$_init$0d1be0f2915bd2a4(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AQuotedName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AQuotedName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *);
extern struct _jc_soot_jimple_parser_node_TQuotedName$object *_jc_soot_jimple_parser_node_AQuotedName$method$getQuotedName$c1052124678e1334(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *);
extern void _jc_soot_jimple_parser_node_AQuotedName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AQuotedName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AQuotedName$method$setQuotedName$191e6d0cc56dd3f2(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AQuotedName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$getQuotedName$c1052124678e1334;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$setQuotedName$191e6d0cc56dd3f2;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AQuotedName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *);
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*(*getQuotedName$c1052124678e1334)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setQuotedName$191e6d0cc56dd3f2)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AQuotedName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PName$vmethods	soot_jimple_parser_node_PName;
	_jc_soot_jimple_parser_node_AQuotedName$vmethods	soot_jimple_parser_node_AQuotedName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AQuotedName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AQuotedName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedName$sub_refs {
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*__5fquotedName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedName$refs {
    _jc_soot_jimple_parser_node_AQuotedName$sub_refs	soot_jimple_parser_node_AQuotedName;
    _jc_soot_jimple_parser_node_PName$sub_refs	soot_jimple_parser_node_PName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PName$sub_nonrefs	soot_jimple_parser_node_PName;
    _jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs	soot_jimple_parser_node_AQuotedName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AQuotedName$object {
	_jc_soot_jimple_parser_node_AQuotedName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AQuotedName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AQuotedName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AQuotedName$vtype _jc_soot_jimple_parser_node_AQuotedName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AQuotedName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AQuotedName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AQuotedName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AQuotedName.h <==
// public final class soot.jimple.parser.node.AQuotedName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 57a68fb97992878e soot_jimple_parser_node_AQuotedName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class a249bf92047679aa soot_jimple_parser_node_PName

// header file dependencies
// @dep_header soot_jimple_parser_node_PName

#include "soot/jimple/parser/node/PName.h"

#ifndef _JC_soot_jimple_parser_node_AQuotedName_H_
#define _JC_soot_jimple_parser_node_AQuotedName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TQuotedName$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AQuotedName$sub_refs	_jc_soot_jimple_parser_node_AQuotedName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs	_jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$refs	_jc_soot_jimple_parser_node_AQuotedName$refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$nonrefs	_jc_soot_jimple_parser_node_AQuotedName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedName$object	_jc_soot_jimple_parser_node_AQuotedName$object;

typedef const struct _jc_soot_jimple_parser_node_AQuotedName$vmethods	_jc_soot_jimple_parser_node_AQuotedName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AQuotedName$vtable	_jc_soot_jimple_parser_node_AQuotedName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AQuotedName$vtype	_jc_soot_jimple_parser_node_AQuotedName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AQuotedName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedName$method$_init$0d1be0f2915bd2a4(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AQuotedName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AQuotedName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TQuotedName$object *_jc_soot_jimple_parser_node_AQuotedName$method$getQuotedName$c1052124678e1334(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedName$method$setQuotedName$191e6d0cc56dd3f2(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AQuotedName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$getQuotedName$c1052124678e1334;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$setQuotedName$191e6d0cc56dd3f2;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AQuotedName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*(*getQuotedName$c1052124678e1334)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setQuotedName$191e6d0cc56dd3f2)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AQuotedName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PName$vmethods	soot_jimple_parser_node_PName;
	_jc_soot_jimple_parser_node_AQuotedName$vmethods	soot_jimple_parser_node_AQuotedName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AQuotedName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AQuotedName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedName$sub_refs {
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*__5fquotedName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedName$refs {
    _jc_soot_jimple_parser_node_AQuotedName$sub_refs	soot_jimple_parser_node_AQuotedName;
    _jc_soot_jimple_parser_node_PName$sub_refs	soot_jimple_parser_node_PName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PName$sub_nonrefs	soot_jimple_parser_node_PName;
    _jc_soot_jimple_parser_node_AQuotedName$sub_nonrefs	soot_jimple_parser_node_AQuotedName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AQuotedName$object {
	_jc_soot_jimple_parser_node_AQuotedName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AQuotedName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AQuotedName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AQuotedName$vtype _jc_soot_jimple_parser_node_AQuotedName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AQuotedName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AQuotedName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AQuotedName_H_ */
